@@ -1,4 +1,4 @@
-from print_manager import mcprint, Color
+from .print_manager import mcprint, Color
 
 def print_error(operators_list = None, contains_list = None, return_type=None):
     return
